@@ -13,23 +13,23 @@ import libcoveocds.config
 
 
 class SchemaOCDS(SchemaJsonMixin):
-
-    def __init__(self, select_version=None, release_data=None, cache_schema=False, lib_cove_ocds_config=None,
-                 record_pkg=False):
-        '''Build the schema object using an specific OCDS schema version
+    def __init__(
+        self, select_version=None, release_data=None, cache_schema=False, lib_cove_ocds_config=None, record_pkg=False
+    ):
+        """Build the schema object using an specific OCDS schema version
 
         The version used will be select_version, release_data.get('version') or
         default version, in that order. Invalid version choices in select_version or
         release_data will be skipped and registered as self.invalid_version_argument
         and self.invalid_version_data respectively.
-        '''
+        """
 
         self.config = lib_cove_ocds_config or libcoveocds.config.LibCoveOCDSConfig()
-        self.schema_name = self.config.config['schema_item_name']
-        self.pkg_schema_name = self.config.config['schema_name']['release']
+        self.schema_name = self.config.config["schema_item_name"]
+        self.pkg_schema_name = self.config.config["schema_name"]["release"]
         self.record_pkg = record_pkg
         if record_pkg:
-            self.pkg_schema_name = self.config.config['schema_name']['record']
+            self.pkg_schema_name = self.config.config["schema_name"]["record"]
             self.release_schema = SchemaOCDS(
                 select_version=select_version,
                 release_data=release_data,
@@ -37,8 +37,8 @@ class SchemaOCDS(SchemaJsonMixin):
                 lib_cove_ocds_config=lib_cove_ocds_config,
                 record_pkg=False,
             )
-        self.version_choices = self.config.config['schema_version_choices']
-        self.default_version = self.config.config['schema_version']
+        self.version_choices = self.config.config["schema_version_choices"]
+        self.default_version = self.config.config["schema_version"]
         self.default_schema_host = self.version_choices[self.default_version][1]
 
         self.version = self.default_version
@@ -46,15 +46,15 @@ class SchemaOCDS(SchemaJsonMixin):
 
         # cache_schema is a deprecated option - now set cache_all_requests in the config instead.
         if cache_schema:
-            self.config.config['cache_all_requests'] = True
+            self.config.config["cache_all_requests"] = True
 
         # Missing package is only for original json data
         self.missing_package = False
         if release_data:
-            if 'version' not in release_data:
-                self.version = '1.0'
-                self.schema_host = self.version_choices['1.0'][1]
-            if 'releases' not in release_data and 'records' not in release_data:
+            if "version" not in release_data:
+                self.version = "1.0"
+                self.schema_host = self.version_choices["1.0"][1]
+            if "releases" not in release_data and "records" not in release_data:
                 self.missing_package = True
 
         self.invalid_version_argument = False
@@ -65,7 +65,7 @@ class SchemaOCDS(SchemaJsonMixin):
         self.extended = False
         self.extended_schema_file = None
         self.extended_schema_url = None
-        self.codelists = self.config.config['schema_codelists']['1.1']
+        self.codelists = self.config.config["schema_codelists"]["1.1"]
 
         if select_version:
             try:
@@ -77,12 +77,12 @@ class SchemaOCDS(SchemaJsonMixin):
                 self.version = select_version
                 self.schema_host = self.version_choices[select_version][1]
 
-        if hasattr(release_data, 'get'):
-            data_extensions = release_data.get('extensions', {})
+        if hasattr(release_data, "get"):
+            data_extensions = release_data.get("extensions", {})
             if data_extensions:
                 self.extensions = OrderedDict((ext, tuple()) for ext in data_extensions if type(ext) == str)
             if not select_version:
-                release_version = release_data and release_data.get('version')
+                release_version = release_data and release_data.get("version")
                 if release_version:
                     version_choice = self.version_choices.get(release_version)
                     if version_choice:
@@ -118,26 +118,28 @@ class SchemaOCDS(SchemaJsonMixin):
             if not codelist_list:
                 continue
 
-            base_url = "/".join(extension.split('/')[:-1]) + "/codelists/"
+            base_url = "/".join(extension.split("/")[:-1]) + "/codelists/"
 
             for codelist in codelist_list:
                 try:
                     codelist_map = load_codelist(base_url + codelist, config=self.config)
                 except UnicodeDecodeError:
-                    extension_detail['failed_codelists'][codelist] = "Unicode Error, codelists need to be in UTF-8"
+                    extension_detail["failed_codelists"][codelist] = "Unicode Error, codelists need to be in UTF-8"
                 except Exception as e:
-                    extension_detail['failed_codelists'][codelist] = "Unknown Exception, {}".format(str(e))
+                    extension_detail["failed_codelists"][codelist] = "Unknown Exception, {}".format(str(e))
                     continue
 
                 if not codelist_map:
-                    extension_detail['failed_codelists'][
-                        codelist] = "Codelist Error, Could not find code field in codelist"
+                    extension_detail["failed_codelists"][
+                        codelist
+                    ] = "Codelist Error, Could not find code field in codelist"
 
                 if codelist[0] in ("+", "-"):
                     codelist_extension = codelist[1:]
                     if codelist_extension not in self.extended_codelists:
-                        extension_detail['failed_codelists'][codelist] = \
-                            "Extension error, Trying to extend non existing codelist {}".format(codelist_extension)
+                        extension_detail["failed_codelists"][
+                            codelist
+                        ] = "Extension error, Trying to extend non existing codelist {}".format(codelist_extension)
                         continue
 
                 if codelist[0] == "+":
@@ -146,8 +148,9 @@ class SchemaOCDS(SchemaJsonMixin):
                     for code in codelist_map:
                         value = self.extended_codelists[codelist_extension].pop(code, None)
                         if not value:
-                            extension_detail['failed_codelists'][codelist] = \
-                                "Codelist error, Trying to remove non existing codelist value {}".format(code)
+                            extension_detail["failed_codelists"][
+                                codelist
+                            ] = "Codelist error, Trying to remove non existing codelist value {}".format(code)
                 else:
                     self.extended_codelists[codelist] = codelist_map
 
@@ -180,16 +183,18 @@ class SchemaOCDS(SchemaJsonMixin):
                 if self.record_pkg:
                     package_schema_obj = self.deref_schema(self.pkg_schema_str)
                     deref_release_schema_obj = self.release_schema.get_schema_obj(deref=True)
-                    package_schema_obj['properties']['records']['items'][
-                        'properties']['compiledRelease'] = deref_release_schema_obj
-                    package_schema_obj['properties']['records']['items'][
-                        'properties']['releases']['oneOf'][1] = deref_release_schema_obj
+                    package_schema_obj["properties"]["records"]["items"]["properties"][
+                        "compiledRelease"
+                    ] = deref_release_schema_obj
+                    package_schema_obj["properties"]["records"]["items"]["properties"]["releases"]["oneOf"][
+                        1
+                    ] = deref_release_schema_obj
                 else:
                     deref_schema_obj = self.get_schema_obj(deref=True)
-                    package_schema_obj['properties']['releases']['items'] = {}
+                    package_schema_obj["properties"]["releases"]["items"] = {}
                     pkg_schema_str = json.dumps(package_schema_obj)
                     package_schema_obj = self.deref_schema(pkg_schema_str)
-                    package_schema_obj['properties']['releases']['items'].update(deref_schema_obj)
+                    package_schema_obj["properties"]["releases"]["items"].update(deref_schema_obj)
 
             else:
                 return self.deref_schema(self.pkg_schema_str)
@@ -204,15 +209,16 @@ class SchemaOCDS(SchemaJsonMixin):
                 response = get_request(extensions_descriptor_url, config=self.config)
                 if not response.ok:
                     # extension descriptor is required to proceed
-                    self.invalid_extension[extensions_descriptor_url] = '{}: {}'.format(
-                        response.status_code, response.reason.lower())
+                    self.invalid_extension[extensions_descriptor_url] = "{}: {}".format(
+                        response.status_code, response.reason.lower()
+                    )
                     continue
             except requests.exceptions.RequestException:
-                self.invalid_extension[extensions_descriptor_url] = 'fetching failed'
+                self.invalid_extension[extensions_descriptor_url] = "fetching failed"
                 continue
 
-            i = extensions_descriptor_url.rfind('/')
-            url = '{}/{}'.format(extensions_descriptor_url[:i], 'release-schema.json')
+            i = extensions_descriptor_url.rfind("/")
+            url = "{}/{}".format(extensions_descriptor_url[:i], "release-schema.json")
 
             try:
                 extension = get_request(url, config=self.config)
@@ -223,14 +229,15 @@ class SchemaOCDS(SchemaJsonMixin):
                 try:
                     extension_data = extension.json()
                 except ValueError:  # would be json.JSONDecodeError for Python 3.5+
-                    self.invalid_extension[extensions_descriptor_url] = 'release schema invalid JSON'
+                    self.invalid_extension[extensions_descriptor_url] = "release schema invalid JSON"
                     continue
             elif extension.status_code == 404:
                 url = None
                 extension_data = {}
             else:
-                self.invalid_extension[extensions_descriptor_url] = '{}: {}'.format(
-                    extension.status_code, extension.reason.lower())
+                self.invalid_extension[extensions_descriptor_url] = "{}: {}".format(
+                    extension.status_code, extension.reason.lower()
+                )
                 continue
 
             schema_obj = json_merge_patch.merge(schema_obj, extension_data)
@@ -239,31 +246,31 @@ class SchemaOCDS(SchemaJsonMixin):
                 extensions_descriptor = response.json()
 
             except ValueError:  # would be json.JSONDecodeError for Python 3.5+
-                self.invalid_extension[extensions_descriptor_url] = 'invalid JSON'
+                self.invalid_extension[extensions_descriptor_url] = "invalid JSON"
                 continue
-            cur_language = self.config.config['current_language']
+            cur_language = self.config.config["current_language"]
 
-            extension_description = {'url': extensions_descriptor_url, 'schema_url': url}
+            extension_description = {"url": extensions_descriptor_url, "schema_url": url}
 
-            for field in ['description', 'name', 'documentationUrl']:
+            for field in ["description", "name", "documentationUrl"]:
                 field_object = extensions_descriptor.get(field, {})
                 if isinstance(field_object, str):
                     field_value = field_object
                 else:
                     field_value = field_object.get(cur_language)
                     if not field_value:
-                        field_value = field_object.get('en', '')
+                        field_value = field_object.get("en", "")
                 extension_description[field] = field_value
-            extension_description['failed_codelists'] = {}
-            codelists = extensions_descriptor.get('codelists')
+            extension_description["failed_codelists"] = {}
+            codelists = extensions_descriptor.get("codelists")
             if codelists:
-                extension_description['codelists'] = codelists
+                extension_description["codelists"] = codelists
 
             self.extensions[extensions_descriptor_url] = extension_description
             self.extended = True
 
     def create_extended_schema_file(self, upload_dir, upload_url):
-        filepath = os.path.join(upload_dir, 'extended_schema.json')
+        filepath = os.path.join(upload_dir, "extended_schema.json")
 
         # Always replace any existing extended schema file
         if os.path.exists(filepath):
@@ -278,9 +285,9 @@ class SchemaOCDS(SchemaJsonMixin):
         if not self.extended:
             return
 
-        with open(filepath, 'w') as fp:
+        with open(filepath, "w") as fp:
             schema_str = json.dumps(schema_obj, indent=4)
             fp.write(schema_str)
 
         self.extended_schema_file = filepath
-        self.extended_schema_url = urljoin(upload_url, 'extended_schema.json')
+        self.extended_schema_url = urljoin(upload_url, "extended_schema.json")
