@@ -11,21 +11,21 @@ import libcoveocds.schema
 
 # Cache for faster tests.
 config = libcoveocds.config.LibCoveOCDSConfig()
-config.config['cache_all_requests'] = True
+config.config["cache_all_requests"] = True
 
 
 def test_basic_1():
 
-    cove_temp_folder = tempfile.mkdtemp(prefix='libcoveocds-tests-', dir=tempfile.gettempdir())
+    cove_temp_folder = tempfile.mkdtemp(prefix="libcoveocds-tests-", dir=tempfile.gettempdir())
     schema = libcoveocds.schema.SchemaOCDS(lib_cove_ocds_config=config)
-    json_filename = os.path.join(os.path.dirname(
-        os.path.realpath(__file__)), 'fixtures', 'common_checks', 'basic_1.json'
+    json_filename = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "fixtures", "common_checks", "basic_1.json"
     )
     with open(json_filename) as fp:
         json_data = json.load(fp)
 
     context = {
-        'file_type': 'json',
+        "file_type": "json",
     }
 
     try:
@@ -40,21 +40,21 @@ def test_basic_1():
     finally:
         shutil.rmtree(cove_temp_folder)
 
-    assert results['version_used'] == '1.1'
+    assert results["version_used"] == "1.1"
 
 
 def test_dupe_ids_1():
 
-    cove_temp_folder = tempfile.mkdtemp(prefix='libcoveocds-tests-', dir=tempfile.gettempdir())
+    cove_temp_folder = tempfile.mkdtemp(prefix="libcoveocds-tests-", dir=tempfile.gettempdir())
     schema = libcoveocds.schema.SchemaOCDS(lib_cove_ocds_config=config)
-    json_filename = os.path.join(os.path.dirname(
-        os.path.realpath(__file__)), 'fixtures', 'common_checks', 'dupe_ids_1.json'
+    json_filename = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "fixtures", "common_checks", "dupe_ids_1.json"
     )
     with open(json_filename) as fp:
         json_data = json.load(fp)
 
     context = {
-        'file_type': 'json',
+        "file_type": "json",
     }
 
     try:
@@ -70,19 +70,19 @@ def test_dupe_ids_1():
         shutil.rmtree(cove_temp_folder)
 
     # https://github.com/OpenDataServices/cove/issues/782 Defines how we want this error shown
-    assert len(results['validation_errors'][0][1]) == 2
+    assert len(results["validation_errors"][0][1]) == 2
     # test paths
-    assert results['validation_errors'][0][1][0]['path'] == 'releases'
-    assert results['validation_errors'][0][1][1]['path'] == 'releases'
+    assert results["validation_errors"][0][1][0]["path"] == "releases"
+    assert results["validation_errors"][0][1][1]["path"] == "releases"
     # test values
     # we don't know what order they will come out in, so fix the order ourselves
     values = [
-        results['validation_errors'][0][1][0]['value'],
-        results['validation_errors'][0][1][1]['value'],
+        results["validation_errors"][0][1][0]["value"],
+        results["validation_errors"][0][1][1]["value"],
     ]
     values.sort()
-    assert values[0] == 'ocds-213czf-000-00001-01-planning'
-    assert values[1] == 'ocds-213czf-000-00001-02-planning'
+    assert values[0] == "ocds-213czf-000-00001-01-planning"
+    assert values[1] == "ocds-213czf-000-00001-02-planning"
 
 
 @pytest.mark.parametrize(
@@ -97,7 +97,7 @@ def test_dupe_ids_1():
             [
                 {
                     "message": "'date' is missing but required within 'releases'",
-                    "message_safe": "<code>date</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;date&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "embedded_releases",
                     "message_type": "required",
@@ -110,7 +110,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'date' is missing but required within 'releases'",
-                    "message_safe": "<code>date</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;date&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "linked_releases",
                     "message_type": "required",
@@ -126,7 +126,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'initiationType' is missing but required within 'releases'",
-                    "message_safe": "<code>initiationType</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;initiationType&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "embedded_releases",
                     "message_type": "required",
@@ -139,7 +139,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'ocid' is missing but required within 'releases'",
-                    "message_safe": "<code>ocid</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;ocid&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "embedded_releases",
                     "message_type": "required",
@@ -152,7 +152,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'releases' is not a JSON array",
-                    "message_safe": "<code>releases</code> is not a JSON array",
+                    "message_safe": "&#x27;releases&#x27; is not a JSON array",
                     "validator": "type",
                     "assumption": "linked_releases",
                     "message_type": "array",
@@ -169,7 +169,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'tag' is missing but required within 'releases'",
-                    "message_safe": "<code>tag</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;tag&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "embedded_releases",
                     "message_type": "required",
@@ -182,7 +182,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'url' is missing but required within 'releases'",
-                    "message_safe": "<code>url</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;url&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "linked_releases",
                     "message_type": "required",
@@ -194,8 +194,8 @@ def test_dupe_ids_1():
                     "values": [{"path": "records/1/releases/0"}],
                 },
                 {
-                    "message": "This array should contain either entirely embedded releases or linked releases. Embedded releases contain an 'id' whereas linked releases do not. Your releases contain a mixture.", # noqa
-                    "message_safe": "This array should contain either entirely embedded releases or linked releases. Embedded releases contain an &#x27;id&#x27; whereas linked releases do not. Your releases contain a mixture.", # noqa
+                    "message": "This array should contain either entirely embedded releases or linked releases. Embedded releases contain an 'id' whereas linked releases do not. Your releases contain a mixture.",  # noqa: E501
+                    "message_safe": "This array should contain either entirely embedded releases or linked releases. Embedded releases contain an &#x27;id&#x27; whereas linked releases do not. Your releases contain a mixture.",  # noqa: E501
                     "validator": "oneOf",
                     "assumption": None,
                     "message_type": "oneOf",
@@ -211,7 +211,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "[] is too short",
-                    "message_safe": "<code>[]</code> is too short. You must supply at least one value, or remove the item entirely (unless it’s required).", # noqa
+                    "message_safe": "[] is too short",
                     "validator": "minItems",
                     "assumption": "linked_releases",
                     "message_type": "minItems",
@@ -221,6 +221,7 @@ def test_dupe_ids_1():
                     "null_clause": "",
                     "error_id": None,
                     "values": [{"path": "records/0/releases"}],
+                    "instance": [],
                 },
             ],
         ),
@@ -231,7 +232,7 @@ def test_dupe_ids_1():
             [
                 {
                     "message": "'date' is missing but required within 'releases'",
-                    "message_safe": "<code>date</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;date&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "embedded_releases",
                     "message_type": "required",
@@ -244,7 +245,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'date' is missing but required within 'releases'",
-                    "message_safe": "<code>date</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;date&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "linked_releases",
                     "message_type": "required",
@@ -260,7 +261,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'initiationType' is missing but required within 'releases'",
-                    "message_safe": "<code>initiationType</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;initiationType&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "embedded_releases",
                     "message_type": "required",
@@ -273,7 +274,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'ocid' is missing but required within 'releases'",
-                    "message_safe": "<code>ocid</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;ocid&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "embedded_releases",
                     "message_type": "required",
@@ -286,7 +287,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'releases' is not a JSON array",
-                    "message_safe": "<code>releases</code> is not a JSON array",
+                    "message_safe": "&#x27;releases&#x27; is not a JSON array",
                     "validator": "type",
                     "assumption": "linked_releases",
                     "message_type": "array",
@@ -303,7 +304,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'tag' is missing but required within 'releases'",
-                    "message_safe": "<code>tag</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;tag&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "embedded_releases",
                     "message_type": "required",
@@ -316,7 +317,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "'url' is missing but required within 'releases'",
-                    "message_safe": "<code>url</code> is missing but required within <code>releases</code>",
+                    "message_safe": "&#x27;url&#x27; is missing but required within &#x27;releases&#x27;",
                     "validator": "required",
                     "assumption": "linked_releases",
                     "message_type": "required",
@@ -328,8 +329,8 @@ def test_dupe_ids_1():
                     "values": [{"path": "records/1/releases/0"}],
                 },
                 {
-                    "message": "This array should contain either entirely embedded releases or linked releases. Embedded releases contain an 'id' whereas linked releases do not. Your releases contain a mixture.", # noqa
-                    "message_safe": "This array should contain either entirely embedded releases or linked releases. Embedded releases contain an &#x27;id&#x27; whereas linked releases do not. Your releases contain a mixture.", # noqa
+                    "message": "This array should contain either entirely embedded releases or linked releases. Embedded releases contain an 'id' whereas linked releases do not. Your releases contain a mixture.",  # noqa: E501
+                    "message_safe": "This array should contain either entirely embedded releases or linked releases. Embedded releases contain an &#x27;id&#x27; whereas linked releases do not. Your releases contain a mixture.",  # noqa: E501
                     "validator": "oneOf",
                     "assumption": None,
                     "message_type": "oneOf",
@@ -345,7 +346,7 @@ def test_dupe_ids_1():
                 },
                 {
                     "message": "[] is too short",
-                    "message_safe": "<code>[]</code> is too short. You must supply at least one value, or remove the item entirely (unless it’s required).", # noqa
+                    "message_safe": "[] is too short",
                     "validator": "minItems",
                     "assumption": "linked_releases",
                     "message_type": "minItems",
@@ -355,6 +356,7 @@ def test_dupe_ids_1():
                     "null_clause": "",
                     "error_id": None,
                     "values": [{"path": "records/0/releases"}],
+                    "instance": [],
                 },
             ],
         ),
@@ -411,7 +413,7 @@ def test_dupe_ids_1():
             [
                 {
                     "message": "'id' is missing but required",
-                    "message_safe": "<code>id</code> is missing but required",
+                    "message_safe": "&#x27;id&#x27; is missing but required",
                     "validator": "required",
                     "assumption": None,
                     "message_type": "required",
@@ -444,7 +446,7 @@ def test_dupe_ids_1():
             [
                 {
                     "message": "'ocid' is missing but required",
-                    "message_safe": "<code>ocid</code> is missing but required",
+                    "message_safe": "&#x27;ocid&#x27; is missing but required",
                     "validator": "required",
                     "assumption": None,
                     "message_type": "required",
@@ -479,7 +481,7 @@ def test_dupe_ids_1():
             [
                 {
                     "message": "'id' is missing but required",
-                    "message_safe": "<code>id</code> is missing but required",
+                    "message_safe": "&#x27;id&#x27; is missing but required",
                     "validator": "required",
                     "assumption": None,
                     "message_type": "required",
@@ -499,7 +501,7 @@ def test_dupe_ids_1():
             [
                 {
                     "message": "'ocid' is missing but required",
-                    "message_safe": "<code>ocid</code> is missing but required",
+                    "message_safe": "&#x27;ocid&#x27; is missing but required",
                     "validator": "required",
                     "assumption": None,
                     "message_type": "required",
@@ -514,9 +516,7 @@ def test_dupe_ids_1():
         ),
     ],
 )
-def test_validation_release_or_record_package(
-    record_pkg, filename, validation_error_jsons_expected, schema_subdir
-):
+def test_validation_release_or_record_package(record_pkg, filename, validation_error_jsons_expected, schema_subdir):
     schema_host = os.path.join(
         os.path.dirname(os.path.realpath(__file__)),
         "fixtures",
@@ -527,10 +527,10 @@ def test_validation_release_or_record_package(
     with open(os.path.join(schema_host, filename)) as fp:
         json_data = json.load(fp)
 
-    cove_temp_folder = tempfile.mkdtemp(prefix='libcoveocds-tests-', dir=tempfile.gettempdir())
+    cove_temp_folder = tempfile.mkdtemp(prefix="libcoveocds-tests-", dir=tempfile.gettempdir())
     schema = libcoveocds.schema.SchemaOCDS(lib_cove_ocds_config=config, record_pkg=record_pkg)
     context = {
-        'file_type': 'json',
+        "file_type": "json",
     }
 
     results = libcoveocds.common_checks.common_checks_ocds(
@@ -540,7 +540,7 @@ def test_validation_release_or_record_package(
         schema,
     )
 
-    validation_errors = results['validation_errors']
+    validation_errors = results["validation_errors"]
 
     validation_error_jsons = []
     for validation_error_json, values in validation_errors:
@@ -558,4 +558,10 @@ def test_validation_release_or_record_package(
             del validation_error_json["schema_title"]
         validation_error_jsons.append(validation_error_json)
 
-    assert validation_error_jsons == validation_error_jsons_expected
+    def strip_nones(list_of_dicts):
+        out = []
+        for a_dict in list_of_dicts:
+            out.append({key: value for key, value in a_dict.items() if value is not None})
+        return out
+
+    assert strip_nones(validation_error_jsons) == strip_nones(validation_error_jsons_expected)
